==> db.js-0.13.2.tgz: package/karma.conf.js <==
// Karma configuration
// Generated on Fri Feb 26 2016 11:48:37 GMT+1100 (AUS Eastern Summer Time)

module.exports = function(config) {
  config.set({

    // base path that will be used to resolve all patterns (eg. files, exclude)
    basePath: '',


    // frameworks to use
    // available frameworks: https://npmjs.org/browse/keyword/karma-adapter
    frameworks: ['mocha'],


    // list of files / patterns to load in the browser
    files: [
      'node_modules/es6-promise/dist/es6-promise.js',
      'dist/db.min.js',
      'node_modules/chai/chai.js',
      'tests/helpers/**/*.js',
      'tests/specs/**/*.js'
    ],


    // list of files to exclude
    exclude: [
        // exclude the jQuery integraion tests for karma
        'tests/specs/thenable-integration.js',
        // phantom doesn't support web workers
        'tests/specs/web-workers.js'
    ],


    // preprocess matching files before serving them to the browser
    // available preprocessors: https://npmjs.org/browse/keyword/karma-preprocessor
    preprocessors: {
    },


    // test results reporter to use
    // possible values: 'dots', 'progress'
    // available reporters: https://npmjs.org/browse/keyword/karma-reporter
    reporters: ['progress'],


    // web server port
    port: 9876,


    // enable / disable colors in the output (reporters and logs)
    colors: true,


    // level of logging
    // possible values: config.LOG_DISABLE || config.LOG_ERROR || config.LOG_WARN || config.LOG_INFO || config.LOG_DEBUG
    logLevel: config.LOG_INFO,


    // enable / disable watching file and executing tests whenever any file changes
    autoWatch: true,


    // start these browsers
    // available browser launchers: https://npmjs.org/browse/keyword/karma-launcher
    browsers: ['PhantomJS'],


    // Continuous Integration mode
    // if true, Karma captures browsers, runs the tests and exits
    singleRun: false,

    // Concurrency level
    // how many browser should be started simultaneous
    concurrency: Infinity,

    customLaunchers: {
        'PhantomJS_custom': {
        base: 'PhantomJS',
        options: {
          windowName: 'my-window',
        },
        flags: ['--load-images=true'],
        debug: true
      }

    }
  })
};

==> db.js-0.14.0.tgz: package/karma.conf.js <==
// Karma configuration
// Generated on Fri Feb 26 2016 11:48:37 GMT+1100 (AUS Eastern Summer Time)

module.exports = function(config) {
  config.set({

    // base path that will be used to resolve all patterns (eg. files, exclude)
    basePath: '',

    client: {
      captureConsole: true,
      mocha: {
        bail: true
      }
    },

    // frameworks to use
    // available frameworks: https://npmjs.org/browse/keyword/karma-adapter
    frameworks: ['mocha'],


    // list of files / patterns to load in the browser
    files: [
      'node_modules/babel-polyfill/dist/polyfill.js',
      'dist/db.min.js',
      'node_modules/chai/chai.js',
      'tests/helpers/**/*.js',
      'tests/specs/**/*.js'
    ],


    // list of files to exclude
    exclude: [
        // exclude the jQuery integration tests for karma
        'tests/specs/thenable-integration.js',
        // phantom doesn't support web workers
        'tests/specs/web-workers.js'
    ],


    // preprocess matching files before serving them to the browser
    // available preprocessors: https://npmjs.org/browse/keyword/karma-preprocessor
    preprocessors: {
    },


    // test results reporter to use
    // possible values: 'dots', 'progress'
    // available reporters: https://npmjs.org/browse/keyword/karma-reporter
    reporters: ['progress'],


    // web server port
    port: 9876,


    // enable / disable colors in the output (reporters and logs)
    colors: true,


    // level of logging
    // possible values: config.LOG_DISABLE || config.LOG_ERROR || config.LOG_WARN || config.LOG_INFO || config.LOG_DEBUG
    logLevel: config.LOG_INFO,


    // enable / disable watching file and executing tests whenever any file changes
    autoWatch: true,


    // start these browsers
    // available browser launchers: https://npmjs.org/browse/keyword/karma-launcher
    browsers: ['PhantomJS'],


    // Continuous Integration mode
    // if true, Karma captures browsers, runs the tests and exits
    singleRun: false,

    // Concurrency level
    // how many browser should be started simultaneous
    concurrency: Infinity,

    customLaunchers: {
        'PhantomJS_custom': {
        base: 'PhantomJS',
        options: {
          windowName: 'my-window',
        },
        flags: ['--load-images=true'],
        debug: true
      }

    }
  })
};
